# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/services/conversion_action_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.resources import conversion_action_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_conversion__action__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/services/conversion_action_service.proto',
  package='google.ads.googleads.v0.services',
  syntax='proto3',
  serialized_pb=_b('\nFgoogle/ads/googleads_v0/proto/services/conversion_action_service.proto\x12 google.ads.googleads.v0.services\x1a?google/ads/googleads_v0/proto/resources/conversion_action.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\"3\n\x1aGetConversionActionRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\x86\x01\n\x1eMutateConversionActionsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12O\n\noperations\x18\x02 \x03(\x0b\x32;.google.ads.googleads.v0.services.ConversionActionOperation\"\xf9\x01\n\x19\x43onversionActionOperation\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x45\n\x06\x63reate\x18\x01 \x01(\x0b\x32\x33.google.ads.googleads.v0.resources.ConversionActionH\x00\x12\x45\n\x06update\x18\x02 \x01(\x0b\x32\x33.google.ads.googleads.v0.resources.ConversionActionH\x00\x12\x10\n\x06remove\x18\x03 \x01(\tH\x00\x42\x0b\n\toperation\"r\n\x1fMutateConversionActionsResponse\x12O\n\x07results\x18\x02 \x03(\x0b\x32>.google.ads.googleads.v0.services.MutateConversionActionResult\"5\n\x1cMutateConversionActionResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xc5\x03\n\x17\x43onversionActionService\x12\xc5\x01\n\x13GetConversionAction\x12<.google.ads.googleads.v0.services.GetConversionActionRequest\x1a\x33.google.ads.googleads.v0.resources.ConversionAction\";\x82\xd3\xe4\x93\x02\x35\x12\x33/v0/{resource_name=customers/*/conversionActions/*}\x12\xe1\x01\n\x17MutateConversionActions\x12@.google.ads.googleads.v0.services.MutateConversionActionsRequest\x1a\x41.google.ads.googleads.v0.services.MutateConversionActionsResponse\"A\x82\xd3\xe4\x93\x02;\"6/v0/customers/{customer_id=*}/conversionActions:mutate:\x01*B\xdc\x01\n$com.google.ads.googleads.v0.servicesB\x1c\x43onversionActionServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V0.Services\xca\x02 Google\\Ads\\GoogleAds\\V0\\Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_conversion__action__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,])




_GETCONVERSIONACTIONREQUEST = _descriptor.Descriptor(
  name='GetConversionActionRequest',
  full_name='google.ads.googleads.v0.services.GetConversionActionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.GetConversionActionRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=237,
  serialized_end=288,
)


_MUTATECONVERSIONACTIONSREQUEST = _descriptor.Descriptor(
  name='MutateConversionActionsRequest',
  full_name='google.ads.googleads.v0.services.MutateConversionActionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v0.services.MutateConversionActionsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v0.services.MutateConversionActionsRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=291,
  serialized_end=425,
)


_CONVERSIONACTIONOPERATION = _descriptor.Descriptor(
  name='ConversionActionOperation',
  full_name='google.ads.googleads.v0.services.ConversionActionOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v0.services.ConversionActionOperation.update_mask', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v0.services.ConversionActionOperation.create', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='google.ads.googleads.v0.services.ConversionActionOperation.update', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v0.services.ConversionActionOperation.remove', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v0.services.ConversionActionOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=428,
  serialized_end=677,
)


_MUTATECONVERSIONACTIONSRESPONSE = _descriptor.Descriptor(
  name='MutateConversionActionsResponse',
  full_name='google.ads.googleads.v0.services.MutateConversionActionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v0.services.MutateConversionActionsResponse.results', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=679,
  serialized_end=793,
)


_MUTATECONVERSIONACTIONRESULT = _descriptor.Descriptor(
  name='MutateConversionActionResult',
  full_name='google.ads.googleads.v0.services.MutateConversionActionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.MutateConversionActionResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=795,
  serialized_end=848,
)

_MUTATECONVERSIONACTIONSREQUEST.fields_by_name['operations'].message_type = _CONVERSIONACTIONOPERATION
_CONVERSIONACTIONOPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_CONVERSIONACTIONOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_conversion__action__pb2._CONVERSIONACTION
_CONVERSIONACTIONOPERATION.fields_by_name['update'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_conversion__action__pb2._CONVERSIONACTION
_CONVERSIONACTIONOPERATION.oneofs_by_name['operation'].fields.append(
  _CONVERSIONACTIONOPERATION.fields_by_name['create'])
_CONVERSIONACTIONOPERATION.fields_by_name['create'].containing_oneof = _CONVERSIONACTIONOPERATION.oneofs_by_name['operation']
_CONVERSIONACTIONOPERATION.oneofs_by_name['operation'].fields.append(
  _CONVERSIONACTIONOPERATION.fields_by_name['update'])
_CONVERSIONACTIONOPERATION.fields_by_name['update'].containing_oneof = _CONVERSIONACTIONOPERATION.oneofs_by_name['operation']
_CONVERSIONACTIONOPERATION.oneofs_by_name['operation'].fields.append(
  _CONVERSIONACTIONOPERATION.fields_by_name['remove'])
_CONVERSIONACTIONOPERATION.fields_by_name['remove'].containing_oneof = _CONVERSIONACTIONOPERATION.oneofs_by_name['operation']
_MUTATECONVERSIONACTIONSRESPONSE.fields_by_name['results'].message_type = _MUTATECONVERSIONACTIONRESULT
DESCRIPTOR.message_types_by_name['GetConversionActionRequest'] = _GETCONVERSIONACTIONREQUEST
DESCRIPTOR.message_types_by_name['MutateConversionActionsRequest'] = _MUTATECONVERSIONACTIONSREQUEST
DESCRIPTOR.message_types_by_name['ConversionActionOperation'] = _CONVERSIONACTIONOPERATION
DESCRIPTOR.message_types_by_name['MutateConversionActionsResponse'] = _MUTATECONVERSIONACTIONSRESPONSE
DESCRIPTOR.message_types_by_name['MutateConversionActionResult'] = _MUTATECONVERSIONACTIONRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetConversionActionRequest = _reflection.GeneratedProtocolMessageType('GetConversionActionRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCONVERSIONACTIONREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.conversion_action_service_pb2'
  ,
  __doc__ = """Request message for [ConversionActionService.GetConversionAction].
  
  
  Attributes:
      resource_name:
          The resource name of the conversion action to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.GetConversionActionRequest)
  ))
_sym_db.RegisterMessage(GetConversionActionRequest)

MutateConversionActionsRequest = _reflection.GeneratedProtocolMessageType('MutateConversionActionsRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECONVERSIONACTIONSREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.conversion_action_service_pb2'
  ,
  __doc__ = """Request message for [ConversionActionService.MutateConversionActions].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose conversion actions are being
          modified.
      operations:
          The list of operations to perform on individual conversion
          actions.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateConversionActionsRequest)
  ))
_sym_db.RegisterMessage(MutateConversionActionsRequest)

ConversionActionOperation = _reflection.GeneratedProtocolMessageType('ConversionActionOperation', (_message.Message,), dict(
  DESCRIPTOR = _CONVERSIONACTIONOPERATION,
  __module__ = 'google.ads.google_ads.v0.proto.services.conversion_action_service_pb2'
  ,
  __doc__ = """A single operation (create, update, remove) on a conversion action.
  
  
  Attributes:
      update_mask:
          FieldMask that determines which resource fields are modified
          in an update.
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          conversion action.
      update:
          Update operation: The conversion action is expected to have a
          valid resource name.
      remove:
          Remove operation: A resource name for the removed conversion
          action is expected, in this format:  ``customers/{customer_id}
          /conversionActions/{conversion_action_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.ConversionActionOperation)
  ))
_sym_db.RegisterMessage(ConversionActionOperation)

MutateConversionActionsResponse = _reflection.GeneratedProtocolMessageType('MutateConversionActionsResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECONVERSIONACTIONSRESPONSE,
  __module__ = 'google.ads.google_ads.v0.proto.services.conversion_action_service_pb2'
  ,
  __doc__ = """Response message for conversion action mutate.
  
  
  Attributes:
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateConversionActionsResponse)
  ))
_sym_db.RegisterMessage(MutateConversionActionsResponse)

MutateConversionActionResult = _reflection.GeneratedProtocolMessageType('MutateConversionActionResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECONVERSIONACTIONRESULT,
  __module__ = 'google.ads.google_ads.v0.proto.services.conversion_action_service_pb2'
  ,
  __doc__ = """The result for the conversion action mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateConversionActionResult)
  ))
_sym_db.RegisterMessage(MutateConversionActionResult)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n$com.google.ads.googleads.v0.servicesB\034ConversionActionServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V0.Services\312\002 Google\\Ads\\GoogleAds\\V0\\Services'))

_CONVERSIONACTIONSERVICE = _descriptor.ServiceDescriptor(
  name='ConversionActionService',
  full_name='google.ads.googleads.v0.services.ConversionActionService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=851,
  serialized_end=1304,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetConversionAction',
    full_name='google.ads.googleads.v0.services.ConversionActionService.GetConversionAction',
    index=0,
    containing_service=None,
    input_type=_GETCONVERSIONACTIONREQUEST,
    output_type=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_conversion__action__pb2._CONVERSIONACTION,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0025\0223/v0/{resource_name=customers/*/conversionActions/*}')),
  ),
  _descriptor.MethodDescriptor(
    name='MutateConversionActions',
    full_name='google.ads.googleads.v0.services.ConversionActionService.MutateConversionActions',
    index=1,
    containing_service=None,
    input_type=_MUTATECONVERSIONACTIONSREQUEST,
    output_type=_MUTATECONVERSIONACTIONSRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002;\"6/v0/customers/{customer_id=*}/conversionActions:mutate:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_CONVERSIONACTIONSERVICE)

DESCRIPTOR.services_by_name['ConversionActionService'] = _CONVERSIONACTIONSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/services/keyword_plan_ad_group_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.resources import keyword_plan_ad_group_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_keyword__plan__ad__group__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/services/keyword_plan_ad_group_service.proto',
  package='google.ads.googleads.v0.services',
  syntax='proto3',
  serialized_pb=_b('\nJgoogle/ads/googleads_v0/proto/services/keyword_plan_ad_group_service.proto\x12 google.ads.googleads.v0.services\x1a\x43google/ads/googleads_v0/proto/resources/keyword_plan_ad_group.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\"5\n\x1cGetKeywordPlanAdGroupRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\x8a\x01\n MutateKeywordPlanAdGroupsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12Q\n\noperations\x18\x02 \x03(\x0b\x32=.google.ads.googleads.v0.services.KeywordPlanAdGroupOperation\"\xff\x01\n\x1bKeywordPlanAdGroupOperation\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12G\n\x06\x63reate\x18\x01 \x01(\x0b\x32\x35.google.ads.googleads.v0.resources.KeywordPlanAdGroupH\x00\x12G\n\x06update\x18\x02 \x01(\x0b\x32\x35.google.ads.googleads.v0.resources.KeywordPlanAdGroupH\x00\x12\x10\n\x06remove\x18\x03 \x01(\tH\x00\x42\x0b\n\toperation\"v\n!MutateKeywordPlanAdGroupsResponse\x12Q\n\x07results\x18\x02 \x03(\x0b\x32@.google.ads.googleads.v0.services.MutateKeywordPlanAdGroupResult\"7\n\x1eMutateKeywordPlanAdGroupResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xd7\x03\n\x19KeywordPlanAdGroupService\x12\xcd\x01\n\x15GetKeywordPlanAdGroup\x12>.google.ads.googleads.v0.services.GetKeywordPlanAdGroupRequest\x1a\x35.google.ads.googleads.v0.resources.KeywordPlanAdGroup\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/v0/{resource_name=customers/*/keywordPlanAdGroups/*}\x12\xe9\x01\n\x19MutateKeywordPlanAdGroups\x12\x42.google.ads.googleads.v0.services.MutateKeywordPlanAdGroupsRequest\x1a\x43.google.ads.googleads.v0.services.MutateKeywordPlanAdGroupsResponse\"C\x82\xd3\xe4\x93\x02=\"8/v0/customers/{customer_id=*}/keywordPlanAdGroups:mutate:\x01*B\xde\x01\n$com.google.ads.googleads.v0.servicesB\x1eKeywordPlanAdGroupServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V0.Services\xca\x02 Google\\Ads\\GoogleAds\\V0\\Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_keyword__plan__ad__group__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,])




_GETKEYWORDPLANADGROUPREQUEST = _descriptor.Descriptor(
  name='GetKeywordPlanAdGroupRequest',
  full_name='google.ads.googleads.v0.services.GetKeywordPlanAdGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.GetKeywordPlanAdGroupRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=245,
  serialized_end=298,
)


_MUTATEKEYWORDPLANADGROUPSREQUEST = _descriptor.Descriptor(
  name='MutateKeywordPlanAdGroupsRequest',
  full_name='google.ads.googleads.v0.services.MutateKeywordPlanAdGroupsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v0.services.MutateKeywordPlanAdGroupsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v0.services.MutateKeywordPlanAdGroupsRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=301,
  serialized_end=439,
)


_KEYWORDPLANADGROUPOPERATION = _descriptor.Descriptor(
  name='KeywordPlanAdGroupOperation',
  full_name='google.ads.googleads.v0.services.KeywordPlanAdGroupOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v0.services.KeywordPlanAdGroupOperation.update_mask', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v0.services.KeywordPlanAdGroupOperation.create', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='google.ads.googleads.v0.services.KeywordPlanAdGroupOperation.update', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v0.services.KeywordPlanAdGroupOperation.remove', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v0.services.KeywordPlanAdGroupOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=442,
  serialized_end=697,
)


_MUTATEKEYWORDPLANADGROUPSRESPONSE = _descriptor.Descriptor(
  name='MutateKeywordPlanAdGroupsResponse',
  full_name='google.ads.googleads.v0.services.MutateKeywordPlanAdGroupsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v0.services.MutateKeywordPlanAdGroupsResponse.results', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=699,
  serialized_end=817,
)


_MUTATEKEYWORDPLANADGROUPRESULT = _descriptor.Descriptor(
  name='MutateKeywordPlanAdGroupResult',
  full_name='google.ads.googleads.v0.services.MutateKeywordPlanAdGroupResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.MutateKeywordPlanAdGroupResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=819,
  serialized_end=874,
)

_MUTATEKEYWORDPLANADGROUPSREQUEST.fields_by_name['operations'].message_type = _KEYWORDPLANADGROUPOPERATION
_KEYWORDPLANADGROUPOPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_KEYWORDPLANADGROUPOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_keyword__plan__ad__group__pb2._KEYWORDPLANADGROUP
_KEYWORDPLANADGROUPOPERATION.fields_by_name['update'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_keyword__plan__ad__group__pb2._KEYWORDPLANADGROUP
_KEYWORDPLANADGROUPOPERATION.oneofs_by_name['operation'].fields.append(
  _KEYWORDPLANADGROUPOPERATION.fields_by_name['create'])
_KEYWORDPLANADGROUPOPERATION.fields_by_name['create'].containing_oneof = _KEYWORDPLANADGROUPOPERATION.oneofs_by_name['operation']
_KEYWORDPLANADGROUPOPERATION.oneofs_by_name['operation'].fields.append(
  _KEYWORDPLANADGROUPOPERATION.fields_by_name['update'])
_KEYWORDPLANADGROUPOPERATION.fields_by_name['update'].containing_oneof = _KEYWORDPLANADGROUPOPERATION.oneofs_by_name['operation']
_KEYWORDPLANADGROUPOPERATION.oneofs_by_name['operation'].fields.append(
  _KEYWORDPLANADGROUPOPERATION.fields_by_name['remove'])
_KEYWORDPLANADGROUPOPERATION.fields_by_name['remove'].containing_oneof = _KEYWORDPLANADGROUPOPERATION.oneofs_by_name['operation']
_MUTATEKEYWORDPLANADGROUPSRESPONSE.fields_by_name['results'].message_type = _MUTATEKEYWORDPLANADGROUPRESULT
DESCRIPTOR.message_types_by_name['GetKeywordPlanAdGroupRequest'] = _GETKEYWORDPLANADGROUPREQUEST
DESCRIPTOR.message_types_by_name['MutateKeywordPlanAdGroupsRequest'] = _MUTATEKEYWORDPLANADGROUPSREQUEST
DESCRIPTOR.message_types_by_name['KeywordPlanAdGroupOperation'] = _KEYWORDPLANADGROUPOPERATION
DESCRIPTOR.message_types_by_name['MutateKeywordPlanAdGroupsResponse'] = _MUTATEKEYWORDPLANADGROUPSRESPONSE
DESCRIPTOR.message_types_by_name['MutateKeywordPlanAdGroupResult'] = _MUTATEKEYWORDPLANADGROUPRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetKeywordPlanAdGroupRequest = _reflection.GeneratedProtocolMessageType('GetKeywordPlanAdGroupRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETKEYWORDPLANADGROUPREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.keyword_plan_ad_group_service_pb2'
  ,
  __doc__ = """Request message for
  [KeywordPlanAdGroupService.GetKeywordPlanAdGroup][google.ads.googleads.v0.services.KeywordPlanAdGroupService.GetKeywordPlanAdGroup].
  
  
  Attributes:
      resource_name:
          The resource name of the Keyword Plan ad group to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.GetKeywordPlanAdGroupRequest)
  ))
_sym_db.RegisterMessage(GetKeywordPlanAdGroupRequest)

MutateKeywordPlanAdGroupsRequest = _reflection.GeneratedProtocolMessageType('MutateKeywordPlanAdGroupsRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEKEYWORDPLANADGROUPSREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.keyword_plan_ad_group_service_pb2'
  ,
  __doc__ = """Request message for
  [KeywordPlanAdGroupService.MutateKeywordPlanAdGroups][google.ads.googleads.v0.services.KeywordPlanAdGroupService.MutateKeywordPlanAdGroups].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose Keyword Plan ad groups are being
          modified.
      operations:
          The list of operations to perform on individual Keyword Plan
          ad groups.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateKeywordPlanAdGroupsRequest)
  ))
_sym_db.RegisterMessage(MutateKeywordPlanAdGroupsRequest)

KeywordPlanAdGroupOperation = _reflection.GeneratedProtocolMessageType('KeywordPlanAdGroupOperation', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDPLANADGROUPOPERATION,
  __module__ = 'google.ads.google_ads.v0.proto.services.keyword_plan_ad_group_service_pb2'
  ,
  __doc__ = """A single operation (create, update, remove) on a Keyword Plan ad group.
  
  
  Attributes:
      update_mask:
          The FieldMask that determines which resource fields are
          modified in an update.
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          Keyword Plan ad group.
      update:
          Update operation: The Keyword Plan ad group is expected to
          have a valid resource name.
      remove:
          Remove operation: A resource name for the removed Keyword Plan
          ad group is expected, in this format:  ``customers/{customer_i
          d}/keywordPlanAdGroups/{kp_ad_group_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.KeywordPlanAdGroupOperation)
  ))
_sym_db.RegisterMessage(KeywordPlanAdGroupOperation)

MutateKeywordPlanAdGroupsResponse = _reflection.GeneratedProtocolMessageType('MutateKeywordPlanAdGroupsResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEKEYWORDPLANADGROUPSRESPONSE,
  __module__ = 'google.ads.google_ads.v0.proto.services.keyword_plan_ad_group_service_pb2'
  ,
  __doc__ = """Response message for a Keyword Plan ad group mutate.
  
  
  Attributes:
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateKeywordPlanAdGroupsResponse)
  ))
_sym_db.RegisterMessage(MutateKeywordPlanAdGroupsResponse)

MutateKeywordPlanAdGroupResult = _reflection.GeneratedProtocolMessageType('MutateKeywordPlanAdGroupResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEKEYWORDPLANADGROUPRESULT,
  __module__ = 'google.ads.google_ads.v0.proto.services.keyword_plan_ad_group_service_pb2'
  ,
  __doc__ = """The result for the Keyword Plan ad group mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateKeywordPlanAdGroupResult)
  ))
_sym_db.RegisterMessage(MutateKeywordPlanAdGroupResult)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n$com.google.ads.googleads.v0.servicesB\036KeywordPlanAdGroupServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V0.Services\312\002 Google\\Ads\\GoogleAds\\V0\\Services'))

_KEYWORDPLANADGROUPSERVICE = _descriptor.ServiceDescriptor(
  name='KeywordPlanAdGroupService',
  full_name='google.ads.googleads.v0.services.KeywordPlanAdGroupService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=877,
  serialized_end=1348,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetKeywordPlanAdGroup',
    full_name='google.ads.googleads.v0.services.KeywordPlanAdGroupService.GetKeywordPlanAdGroup',
    index=0,
    containing_service=None,
    input_type=_GETKEYWORDPLANADGROUPREQUEST,
    output_type=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_keyword__plan__ad__group__pb2._KEYWORDPLANADGROUP,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0027\0225/v0/{resource_name=customers/*/keywordPlanAdGroups/*}')),
  ),
  _descriptor.MethodDescriptor(
    name='MutateKeywordPlanAdGroups',
    full_name='google.ads.googleads.v0.services.KeywordPlanAdGroupService.MutateKeywordPlanAdGroups',
    index=1,
    containing_service=None,
    input_type=_MUTATEKEYWORDPLANADGROUPSREQUEST,
    output_type=_MUTATEKEYWORDPLANADGROUPSRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002=\"8/v0/customers/{customer_id=*}/keywordPlanAdGroups:mutate:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_KEYWORDPLANADGROUPSERVICE)

DESCRIPTOR.services_by_name['KeywordPlanAdGroupService'] = _KEYWORDPLANADGROUPSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/errors/change_status_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/errors/change_status_error.proto',
  package='google.ads.googleads.v0.errors',
  syntax='proto3',
  serialized_pb=_b('\n>google/ads/googleads_v0/proto/errors/change_status_error.proto\x12\x1egoogle.ads.googleads.v0.errors\"b\n\x15\x43hangeStatusErrorEnum\"I\n\x11\x43hangeStatusError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x16\n\x12START_DATE_TOO_OLD\x10\x03\x42\xcc\x01\n\"com.google.ads.googleads.v0.errorsB\x16\x43hangeStatusErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v0/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V0.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V0\\Errorsb\x06proto3')
)



_CHANGESTATUSERRORENUM_CHANGESTATUSERROR = _descriptor.EnumDescriptor(
  name='ChangeStatusError',
  full_name='google.ads.googleads.v0.errors.ChangeStatusErrorEnum.ChangeStatusError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='START_DATE_TOO_OLD', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=123,
  serialized_end=196,
)
_sym_db.RegisterEnumDescriptor(_CHANGESTATUSERRORENUM_CHANGESTATUSERROR)


_CHANGESTATUSERRORENUM = _descriptor.Descriptor(
  name='ChangeStatusErrorEnum',
  full_name='google.ads.googleads.v0.errors.ChangeStatusErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CHANGESTATUSERRORENUM_CHANGESTATUSERROR,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=98,
  serialized_end=196,
)

_CHANGESTATUSERRORENUM_CHANGESTATUSERROR.containing_type = _CHANGESTATUSERRORENUM
DESCRIPTOR.message_types_by_name['ChangeStatusErrorEnum'] = _CHANGESTATUSERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ChangeStatusErrorEnum = _reflection.GeneratedProtocolMessageType('ChangeStatusErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _CHANGESTATUSERRORENUM,
  __module__ = 'google.ads.google_ads.v0.proto.errors.change_status_error_pb2'
  ,
  __doc__ = """Container for enum describing possible change status errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.errors.ChangeStatusErrorEnum)
  ))
_sym_db.RegisterMessage(ChangeStatusErrorEnum)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\"com.google.ads.googleads.v0.errorsB\026ChangeStatusErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v0/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V0.Errors\312\002\036Google\\Ads\\GoogleAds\\V0\\Errors'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/errors/ad_group_ad_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/errors/ad_group_ad_error.proto',
  package='google.ads.googleads.v0.errors',
  syntax='proto3',
  serialized_pb=_b('\n<google/ads/googleads_v0/proto/errors/ad_group_ad_error.proto\x12\x1egoogle.ads.googleads.v0.errors\"\xcc\x02\n\x12\x41\x64GroupAdErrorEnum\"\xb5\x02\n\x0e\x41\x64GroupAdError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12$\n AD_GROUP_AD_LABEL_DOES_NOT_EXIST\x10\x02\x12$\n AD_GROUP_AD_LABEL_ALREADY_EXISTS\x10\x03\x12\x18\n\x14\x41\x44_NOT_UNDER_ADGROUP\x10\x04\x12\'\n#CANNOT_OPERATE_ON_REMOVED_ADGROUPAD\x10\x05\x12 \n\x1c\x43\x41NNOT_CREATE_DEPRECATED_ADS\x10\x06\x12\x1a\n\x16\x43\x41NNOT_CREATE_TEXT_ADS\x10\x07\x12\x0f\n\x0b\x45MPTY_FIELD\x10\x08\x12\'\n#RESOURCE_REFERENCED_IN_MULTIPLE_OPS\x10\tB\xc9\x01\n\"com.google.ads.googleads.v0.errorsB\x13\x41\x64GroupAdErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v0/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V0.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V0\\Errorsb\x06proto3')
)



_ADGROUPADERRORENUM_ADGROUPADERROR = _descriptor.EnumDescriptor(
  name='AdGroupAdError',
  full_name='google.ads.googleads.v0.errors.AdGroupAdErrorEnum.AdGroupAdError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AD_GROUP_AD_LABEL_DOES_NOT_EXIST', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AD_GROUP_AD_LABEL_ALREADY_EXISTS', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AD_NOT_UNDER_ADGROUP', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_OPERATE_ON_REMOVED_ADGROUPAD', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_CREATE_DEPRECATED_ADS', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_CREATE_TEXT_ADS', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMPTY_FIELD', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESOURCE_REFERENCED_IN_MULTIPLE_OPS', index=9, number=9,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=120,
  serialized_end=429,
)
_sym_db.RegisterEnumDescriptor(_ADGROUPADERRORENUM_ADGROUPADERROR)


_ADGROUPADERRORENUM = _descriptor.Descriptor(
  name='AdGroupAdErrorEnum',
  full_name='google.ads.googleads.v0.errors.AdGroupAdErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ADGROUPADERRORENUM_ADGROUPADERROR,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=97,
  serialized_end=429,
)

_ADGROUPADERRORENUM_ADGROUPADERROR.containing_type = _ADGROUPADERRORENUM
DESCRIPTOR.message_types_by_name['AdGroupAdErrorEnum'] = _ADGROUPADERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AdGroupAdErrorEnum = _reflection.GeneratedProtocolMessageType('AdGroupAdErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _ADGROUPADERRORENUM,
  __module__ = 'google.ads.google_ads.v0.proto.errors.ad_group_ad_error_pb2'
  ,
  __doc__ = """Container for enum describing possible ad group ad errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.errors.AdGroupAdErrorEnum)
  ))
_sym_db.RegisterMessage(AdGroupAdErrorEnum)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\"com.google.ads.googleads.v0.errorsB\023AdGroupAdErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v0/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V0.Errors\312\002\036Google\\Ads\\GoogleAds\\V0\\Errors'))
# @@protoc_insertion_point(module_scope)
